==> mingw-w64-onefetch-2.19.0-1.src.tar.zst: onefetch-2.19.0/manifest/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 26 commits contributed to the release over the course of 247 calendar days.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 5 unique issues were worked on: [#1077](https://github.com/o2sh/onefetch/issues/1077), [#1089](https://github.com/o2sh/onefetch/issues/1089), [#851](https://github.com/o2sh/onefetch/issues/851), [#959](https://github.com/o2sh/onefetch/issues/959), [#981](https://github.com/o2sh/onefetch/issues/981)

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **[#1077](https://github.com/o2sh/onefetch/issues/1077)**
    - Bump cargo_toml from 0.15.2 to 0.15.3 ([`b6ed0f7`](https://github.com/o2sh/onefetch/commit/b6ed0f7b28c4226bfb815ea3e94ddd6a98df930b))
 * **[#1089](https://github.com/o2sh/onefetch/issues/1089)**
    - Bump strum from 0.24.1 to 0.25.0 ([`3071110`](https://github.com/o2sh/onefetch/commit/3071110b80797d14af3a1c782079dc9d11601ca4))
 * **[#851](https://github.com/o2sh/onefetch/issues/851)**
    - Add manifest crate ([`ed96c45`](https://github.com/o2sh/onefetch/commit/ed96c4547d62e1660bd78663be428cad5dc57867))
 * **[#959](https://github.com/o2sh/onefetch/issues/959)**
    - Bump cargo_toml from 0.13.0 to 0.14.1 ([`81f852e`](https://github.com/o2sh/onefetch/commit/81f852ec6ab95714b422b4821d26e5f3536fd78c))
 * **[#981](https://github.com/o2sh/onefetch/issues/981)**
    - Bump cargo_toml from 0.14.1 to 0.15.2 ([`b6dbb62`](https://github.com/o2sh/onefetch/commit/b6dbb62c36cd9f38d4dcfe13dfe99ab608f4ef2a))
 * **Uncategorized**
    - Bump version ([`dccd5a8`](https://github.com/o2sh/onefetch/commit/dccd5a8ccf51f10fb6e38af6b16735b3cac5b315))
    - Cargo changelog --write ([`7eb48ae`](https://github.com/o2sh/onefetch/commit/7eb48ae5c1ef2727a2bb070556aca21506667629))
    - Bump version ([`9cc5e52`](https://github.com/o2sh/onefetch/commit/9cc5e5295bfd678ae157a3fbcd8019ae6f7759e0))
    - Merge branch 'main' of github.com:o2sh/onefetch ([`a91def0`](https://github.com/o2sh/onefetch/commit/a91def08355a096ca54cce477abfc8297cdea478))
    - Cargo changelog --write ([`83197c9`](https://github.com/o2sh/onefetch/commit/83197c9fa2f7ee36fe86af05743431921bdff68e))
    - Bump version ([`e42360d`](https://github.com/o2sh/onefetch/commit/e42360d1569cfab87d2f4d11a8c42e3401bd699f))
    - Cargo changelog --write ([`3d6d600`](https://github.com/o2sh/onefetch/commit/3d6d6001f1120508165e8ec6c1fad3660e316718))
    - Bump version ([`ae536d3`](https://github.com/o2sh/onefetch/commit/ae536d39edaaf55b395f32cea0a3b1b9586a1f15))
    - Cargo changelog --write ([`df0d5e8`](https://github.com/o2sh/onefetch/commit/df0d5e8af774b4c0676a94b81fed88dc10215f51))
    - Bump version ([`ca05166`](https://github.com/o2sh/onefetch/commit/ca05166f22910410f71615e6599e522e3885e64a))
    - Add badges to manifest and image crates readme ([`590c387`](https://github.com/o2sh/onefetch/commit/590c3874638fd7de6ce198d0b6f6d04e35ff5052))
    - Bump version ([`a39623a`](https://github.com/o2sh/onefetch/commit/a39623aee24e8f166cb4cc93aea051bd331dffc7))
    - Bump version ([`0a7fc67`](https://github.com/o2sh/onefetch/commit/0a7fc67bee24a9bfc7367ae6fdaee5bb336852c4))
    - Update changelog ([`f0e6acc`](https://github.com/o2sh/onefetch/commit/f0e6acc7e65756453b59f8f278c114f9d80a981c))
    - Add repository entry to cargo files ([`3bb3bb8`](https://github.com/o2sh/onefetch/commit/3bb3bb8f1cc0d46a444edcc747530cfa61e0ea62))
    - Bump version ([`5873a10`](https://github.com/o2sh/onefetch/commit/5873a10ff76ec9ca71d9425740f39c739cf94370))
    - Add description field to image and manifest crate ([`2888186`](https://github.com/o2sh/onefetch/commit/2888186611d2f3ef2a595d1c0f8a210734f8715c))
    - Bump version ([`fff7713`](https://github.com/o2sh/onefetch/commit/fff7713ad4475e7c2b5d96a56a972061ece38b7e))
    - Bump version ([`2342483`](https://github.com/o2sh/onefetch/commit/2342483ec7ac1ce13ab0ac230699017c194a8e92))
    - Fix symlink for license ([`d8f47e9`](https://github.com/o2sh/onefetch/commit/d8f47e9ac2dfc6422519b564bf2c82cd152916a5))
    - Add symbolic link for manifest license ([`3420dff`](https://github.com/o2sh/onefetch/commit/3420dff08fc7b55a9eeb914d79de9d39bfd20ad2))
</details>

==> mingw-w64-onefetch-2.20.0-2.src.tar.zst: onefetch-2.20.0/manifest/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 30 commits contributed to the release over the course of 382 calendar days.
 - 0 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 8 unique issues were worked on: [#1077](https://github.com/o2sh/onefetch/issues/1077), [#1089](https://github.com/o2sh/onefetch/issues/1089), [#1142](https://github.com/o2sh/onefetch/issues/1142), [#1205](https://github.com/o2sh/onefetch/issues/1205), [#1221](https://github.com/o2sh/onefetch/issues/1221), [#851](https://github.com/o2sh/onefetch/issues/851), [#959](https://github.com/o2sh/onefetch/issues/959), [#981](https://github.com/o2sh/onefetch/issues/981)

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **[#1077](https://github.com/o2sh/onefetch/issues/1077)**
    - Bump cargo_toml from 0.15.2 to 0.15.3 ([`b6ed0f7`](https://github.com/o2sh/onefetch/commit/b6ed0f7b28c4226bfb815ea3e94ddd6a98df930b))
 * **[#1089](https://github.com/o2sh/onefetch/issues/1089)**
    - Bump strum from 0.24.1 to 0.25.0 ([`3071110`](https://github.com/o2sh/onefetch/commit/3071110b80797d14af3a1c782079dc9d11601ca4))
 * **[#1142](https://github.com/o2sh/onefetch/issues/1142)**
    - Use workspace inheritance ([`83462df`](https://github.com/o2sh/onefetch/commit/83462df56b32082caf5718cd1665346765c6ee32))
 * **[#1205](https://github.com/o2sh/onefetch/issues/1205)**
    - Bump cargo_toml from 0.15.3 to 0.17.0 ([`a8a6e2a`](https://github.com/o2sh/onefetch/commit/a8a6e2afa0418cb594d56cb6a989777abaee6910))
 * **[#1221](https://github.com/o2sh/onefetch/issues/1221)**
    - Bump cargo_toml from 0.17.0 to 0.17.1 ([`6cd892d`](https://github.com/o2sh/onefetch/commit/6cd892d70f4ebb422aba8f1a3f48f7aacb74e306))
 * **[#851](https://github.com/o2sh/onefetch/issues/851)**
    - Add manifest crate ([`ed96c45`](https://github.com/o2sh/onefetch/commit/ed96c4547d62e1660bd78663be428cad5dc57867))
 * **[#959](https://github.com/o2sh/onefetch/issues/959)**
    - Bump cargo_toml from 0.13.0 to 0.14.1 ([`81f852e`](https://github.com/o2sh/onefetch/commit/81f852ec6ab95714b422b4821d26e5f3536fd78c))
 * **[#981](https://github.com/o2sh/onefetch/issues/981)**
    - Bump cargo_toml from 0.14.1 to 0.15.2 ([`b6dbb62`](https://github.com/o2sh/onefetch/commit/b6dbb62c36cd9f38d4dcfe13dfe99ab608f4ef2a))
 * **Uncategorized**
    - Cargo changelog --write ([`871f98a`](https://github.com/o2sh/onefetch/commit/871f98a6b99e8ac28445951c545c7c32ca722079))
    - Bump version ([`dccd5a8`](https://github.com/o2sh/onefetch/commit/dccd5a8ccf51f10fb6e38af6b16735b3cac5b315))
    - Cargo changelog --write ([`7eb48ae`](https://github.com/o2sh/onefetch/commit/7eb48ae5c1ef2727a2bb070556aca21506667629))
    - Bump version ([`9cc5e52`](https://github.com/o2sh/onefetch/commit/9cc5e5295bfd678ae157a3fbcd8019ae6f7759e0))
    - Merge branch 'main' of github.com:o2sh/onefetch ([`a91def0`](https://github.com/o2sh/onefetch/commit/a91def08355a096ca54cce477abfc8297cdea478))
    - Cargo changelog --write ([`83197c9`](https://github.com/o2sh/onefetch/commit/83197c9fa2f7ee36fe86af05743431921bdff68e))
    - Bump version ([`e42360d`](https://github.com/o2sh/onefetch/commit/e42360d1569cfab87d2f4d11a8c42e3401bd699f))
    - Cargo changelog --write ([`3d6d600`](https://github.com/o2sh/onefetch/commit/3d6d6001f1120508165e8ec6c1fad3660e316718))
    - Bump version ([`ae536d3`](https://github.com/o2sh/onefetch/commit/ae536d39edaaf55b395f32cea0a3b1b9586a1f15))
    - Cargo changelog --write ([`df0d5e8`](https://github.com/o2sh/onefetch/commit/df0d5e8af774b4c0676a94b81fed88dc10215f51))
    - Bump version ([`ca05166`](https://github.com/o2sh/onefetch/commit/ca05166f22910410f71615e6599e522e3885e64a))
    - Add badges to manifest and image crates readme ([`590c387`](https://github.com/o2sh/onefetch/commit/590c3874638fd7de6ce198d0b6f6d04e35ff5052))
    - Bump version ([`a39623a`](https://github.com/o2sh/onefetch/commit/a39623aee24e8f166cb4cc93aea051bd331dffc7))
    - Bump version ([`0a7fc67`](https://github.com/o2sh/onefetch/commit/0a7fc67bee24a9bfc7367ae6fdaee5bb336852c4))
    - Update changelog ([`f0e6acc`](https://github.com/o2sh/onefetch/commit/f0e6acc7e65756453b59f8f278c114f9d80a981c))
    - Add repository entry to cargo files ([`3bb3bb8`](https://github.com/o2sh/onefetch/commit/3bb3bb8f1cc0d46a444edcc747530cfa61e0ea62))
    - Bump version ([`5873a10`](https://github.com/o2sh/onefetch/commit/5873a10ff76ec9ca71d9425740f39c739cf94370))
    - Add description field to image and manifest crate ([`2888186`](https://github.com/o2sh/onefetch/commit/2888186611d2f3ef2a595d1c0f8a210734f8715c))
    - Bump version ([`fff7713`](https://github.com/o2sh/onefetch/commit/fff7713ad4475e7c2b5d96a56a972061ece38b7e))
    - Bump version ([`2342483`](https://github.com/o2sh/onefetch/commit/2342483ec7ac1ce13ab0ac230699017c194a8e92))
    - Fix symlink for license ([`d8f47e9`](https://github.com/o2sh/onefetch/commit/d8f47e9ac2dfc6422519b564bf2c82cd152916a5))
    - Add symbolic link for manifest license ([`3420dff`](https://github.com/o2sh/onefetch/commit/3420dff08fc7b55a9eeb914d79de9d39bfd20ad2))
</details>
